@@ -18,7 +18,7 @@ NumPy arrays.
 
 Every sound file is represented as a SoundFile object. SoundFiles can
 be created for reading, writing, or both. Each SoundFile has a
-samplerate, a number of channels, and a file format. These can not be
+sample_rate, a number of channels, and a file format. These can not be
 changed at runtime.
 
 A SoundFile has methods for reading and writing data to/from the file.
@@ -26,11 +26,15 @@ Even though every sound file has a fixed file format, reading and
 writing is possible in four different NumPy formats: int16, int32,
 float32 and float64.
 
-At the same time, SoundFiles act as container types, so you can use
+At the same time, SoundFiles act as sequence types, so you can use
 slices to read or write data as well. Since there is no way of
 specifying data formats for slices, the SoundFile will always return
 float32 data for those.
 
+Note that you need to have libsndfile installed in order to use
+PySoundFile. On Windows, you need to rename the library to
+"sndfile.dll".
+
 PySoundFile is BSD licensed.
 (c) 2013, Bastian Bechtold
 
@@ -194,8 +198,8 @@ class SoundFile(object):
     Data can be written to the file using write(), or read from the
     file using read(). Every read and write operation starts at a
     certain position in the file. Reading N frames will change this
-    position by N frames as well. Alternatively, seek(), seek_start(),
-    and seek_end() can be used to set the current position to a frame
+    position by N frames as well. Alternatively, seek() and
+    seek_absolute() can be used to set the current position to a frame
     index offset from the current position, the start of the file, or
     the end of the file, respectively.
 
@@ -217,16 +221,16 @@ class SoundFile(object):
 
     """
 
-    def __init__(self, name, samplerate=0, channels=0, format=0,
-                 file_mode=read_write_mode):
+    def __init__(self, name, sample_rate=0, channels=0, format=0,
+                 mode=read_write_mode):
         """Open a new SoundFile.
 
         If a file is only opened in read_mode or in read_write_mode,
-        no samplerate, channels or file format need to be given. If a
-        file is opened in write_mode, you must provide a samplerate, a
-        number of channels, and a file format. An exception is the RAW
-        data format, which requires these data points for reading as
-        well.
+        no sample_rate, channels or file format need to be given. If a
+        file is opened in write_mode, you must provide a sample_rate,
+        a number of channels, and a file format. An exception is the
+        RAW data format, which requires these data points for reading
+        as well.
 
         File formats consist of three parts OR'ed together:
         - one of the file types from snd_types
@@ -240,17 +244,17 @@ class SoundFile(object):
 
         """
         info = ffi.new("SF_INFO*")
-        info.samplerate = samplerate
+        info.samplerate = sample_rate
         info.channels = channels
         info.format = format
         filename = ffi.new('char[]', name.encode())
-        self._file_mode = file_mode
+        self._file_mode = mode
 
         self._file = _snd.sf_open(filename, self._file_mode, info)
         self._handle_error()
 
         self.frames = info.frames
-        self.samplerate = info.samplerate
+        self.sample_rate = info.sample_rate
         self.channels = info.channels
         self.format = _decodeformat(info.format)
         self.sections = info.sections
@@ -316,8 +320,8 @@ class SoundFile(object):
         # be to seek to the end. Returns the number of frames in the
         # file.
         curr = self.seek(0)
-        length = self.seek_end(0)
-        self.seek(curr)
+        length = self.seek_absolute(-1)
+        self.seek_absolute(curr)
         return(length)
 
     def __getitem__(self, frame):
@@ -334,8 +338,10 @@ class SoundFile(object):
             frame = slice(len(self)+frame.start, frame.stop)
         if frame.stop < 0:
             frame = slice(frame.start, len(self)+frame.stop)
+        if frame.start > frame.stop:
+            frame = slice(frame.stop, frame.start)
         curr = self.seek(0)
-        self.seek_start(frame.start)
+        self.seek_absolute(frame.start)
         data = self.read(frame.stop-frame.start)
         self.seek(curr)
         return data
@@ -361,7 +367,7 @@ class SoundFile(object):
                 "Could not fit data of length %i into slice of length %i" %
                 (len(data), frame.stop-frame.start))
         curr = self.seek(0)
-        self.seek_start(frame.start)
+        self.seek_absolute(frame.start)
         self.write(data)
         self.seek(curr)
         return data
